@@ -4,7 +4,7 @@
 #' @description This function automatically selects appropriate polytomous IRT
 #'   models based on an information criterion (e.g. Corrected AIC), then returns
 #'   factor scores, standard errors and various IRT psychometric information, as
-#'   well as more traditionnal ("CTT") psychometric information. All IRT
+#'   well as more traditional ("CTT") psychometric information. All IRT
 #'   estimation procedures are executed with the package \code{mirt} (Chalmers,
 #'   2012). The non-IRT procedures use packages \code{psych} and \code{irr}.
 #'
@@ -12,39 +12,40 @@
 #'   that so far missing data are not supported. This is the only required
 #'   argument for the function.
 #' @param irt.model A string value with the name of the model to fit. It can be:
-#'   \itemize{
-#'   \item{\code{"auto"} (default) or \code{NULL} : Empirically select the model
-#'   based on an information criterion (see \code{selection.criterion} argument).
-#'  \item{Difference models (more or less constrained versions of the
-#'  Graded Response Model)}
-#'  \itemize{
-#'   \item{\code{"GRM"}: Graded Response Model}
-#'   \item{\code{"CGRM"}: Constrained Graded Response Model (equal discriminations)}
-#'   \item{\code{"GrRSM"}: Graded Rating Scale Model (same category structures)}
-#'   \item{\code{"CGrRSM"}: Constrained Graded Rating Scale Model (same category
-#'   structures and equal discriminations)}
-#'            }
-#'   \item{Divide-by-total models (more or less constrained versions of the
-#'  Generalized Partial Credit Model)}
-#'   \itemize{
-#'   \item{\code{"GPCM"}: Generalized Partial Credit Model}
-#'   \item{\code{"PCM"}: Partial Credit Model (equal discriminations)}
-#'   \item{\code{"GRSM"}: Generalized Rating Scale Model (same
-#'   category structures)}
-#'   \item{\code{"RSM"}: Rating Scale Model (same category structures and
-#'   equal discriminations)}
-#'            }
-#'            }}
-#'   For convenience, models can also be called by their full names
-#'   (e.g. \code{"Generalized Rating Scale Model"}
-#'   or \code{"Generalized Rating Scale"} work.)\cr
-#'   \itemize{
+#' \itemize{
+#'   \item{\code{"auto"} (default) or \code{NULL}: Empirically select the model
+#'     based on an information criterion (see \code{selection.criterion} argument).}
+#'
+#'   \item{Difference models:
+#'     \itemize{
+#'       \item{\code{"GRM"}: Graded Response Model}
+#'       \item{\code{"CGRM"}: Constrained Graded Response Model (equal discriminations)}
+#'       \item{\code{"GrRSM"}: Graded Rating Scale Model (same category structures)}
+#'       \item{\code{"CGrRSM"}: Constrained Graded Rating Scale Model (same category
+#'         structures and equal discriminations)}
+#'     }
+#'   }
+#'
+#'   \item{Divide-by-total models:
+#'     \itemize{
+#'       \item{\code{"GPCM"}: Generalized Partial Credit Model}
+#'       \item{\code{"PCM"}: Partial Credit Model (equal discriminations)}
+#'       \item{\code{"GRSM"}: Generalized Rating Scale Model (same category structures)}
+#'       \item{\code{"RSM"}: Rating Scale Model (same category structures and equal discriminations)}
+#'     }
+#'   }
+#' }
+#'
+#' For convenience, models can also be called by their full names (e.g. \code{"Generalized Rating Scale Model"}).
+#'
+#' \itemize{
 #'   \item{Note: Models where judges are constrained to same category structures (Graded Rating Scale Model,
-#'   Constrained Graded Rating Scale Model, Generalized Rating Scale Model and Rating Scale Model) cannot be fit
-#'   if judges have different observed categories. Judges with unobserved categories are automatically removed
-#'   if these models are called. If the automatic model selection is used,
-#'   these models are ignored in the comparison by default, but this behavior can
-#'   be modified to removing judges in the comparison with \code{remove.judges.with.unobserved.categories = T}.}}
+#'     Constrained Graded Rating Scale Model, Generalized Rating Scale Model and Rating Scale Model)
+#'     cannot be fit if judges have different observed categories. Judges with unobserved
+#'     categories are automatically removed if these models are called. If the automatic
+#'     model selection is used, these models are ignored in the comparison by default,
+#'     but this behavior can be modified by setting \code{remove.judges.with.unobserved.categories = TRUE}.}
+#' }
 #' @param summary A logical to indicate if summary statistics should be
 #'   displayed as messages (default is \code{TRUE}).
 #' @param selection.criterion A string with the criterion for the automatic
@@ -182,7 +183,7 @@ jrt <- function(data,
 
 
   #Recode irt model to auto if NULL
-  if (is.null(irt.model) == TRUE) { irt.model <- "auto"}
+  if (is.null(irt.model)) { irt.model <- "auto"}
 
   #Recode irt models to a standard name
   if (irt.model == "grm" | irt.model == "GRM" | irt.model == "Graded Response Model"| irt.model == "GR"
@@ -223,7 +224,7 @@ jrt <- function(data,
   data <- original.data.as.data.frame
 
   ## Create an index variable to merge later
-  index.vector <- seq(seq(1, dim(data)[1]))
+  index.vector <- seq_len(nrow(data))
   original.data.as.data.frame$index.for.jrt <- index.vector
 
 
@@ -231,7 +232,7 @@ jrt <- function(data,
   # Count
 
   # Select data that contains
-  if (is.null(select.variables.that.contain) != TRUE) {
+  if (!is.null(select.variables.that.contain)) {
     data <- dplyr::select(data, dplyr::contains(select.variables.that.contain))
   }
 
@@ -252,7 +253,7 @@ jrt <- function(data,
   ##### PART BELOW PROBABLY NOT NECESSARY ! NEEDS TESTING
   ## If there are complete missing, output a message, and create index for merging after analysis
   if (count.of.complete.missing.cases > 0) {
-    message(paste(sep = "", count.of.complete.missing.cases, " case(s) with completely missing data detected! They were skipped for analysis." ))
+    message(paste0("\u26A0\uFE0F ", count.of.complete.missing.cases, " case(s) with completely missing data detected! They were skipped for analysis."))
     vector.of.cases.complete.missing <- which(logical.vector.of.complete.missing)
     ## Add index variable to data
     data.with.index <- data
@@ -279,10 +280,10 @@ jrt <- function(data,
   # If response categories is set to auto, estimate it based on the overall min to max (integer sequence)
     if (length(response.categories) == 1) {
       response.categories <- min(psych::describe(data)$min):max(psych::describe(data)$max)
-      if (summary == T) {message("The possible responses detected are: ", paste(response.categories, collapse = "-"))}
+      if (summary == T) {message("\u2139\uFE0F The possible responses detected are: ", paste(response.categories, collapse = "-"))}
     }
    else {
-     if (summary == T) {message("Your selected possible responses are: ", paste(response.categories, collapse = "-"))}
+     if (summary == T) {message("\u2139\uFE0F Your selected possible responses are: ", paste(response.categories, collapse = "-"))}
 }
 
 
@@ -304,7 +305,7 @@ jrt <- function(data,
     numberofjudgesremoved <- dim(x)[2] - dim(data)[2]
     if (message == T) {
       if(numberofjudgesremoved > 0){
-        message(paste(sep="", numberofjudgesremoved, " ",column.names,"(s) did not have all categories observed: It/they was/were removed for model comparisons (this is necessary to fit the Rating Scale models)."))}
+        message(paste0("\u26A0\uFE0F ", numberofjudgesremoved, " ",column.names,"(s) did not have all categories observed: It/they was/were removed for model comparisons (this is necessary to fit the Rating Scale models)."))}
     }
     return(data)
   }
@@ -360,7 +361,9 @@ model.for.constrained.category.structure <- paste(sep = "",
 
 
 
-# Function to decide of
+
+# This is used to store all model objects
+all_mirt_objects <- list()
 
 
 if (irt.model == "auto") {
@@ -431,7 +434,7 @@ if (irt.model == "auto") {
 
   if(progress.bar == T){
   #Message when comparison starts
-  message(paste("\nComparing models...",sep=""))}
+  message(paste("\n\u23F3 Comparing models...",sep=""))}
 
 
   comparisonstatistic <- c()
@@ -455,7 +458,6 @@ if (progress.bar == T) {
 
 
 
-
   for (i in 1:length(irt.modelvector)){
     Sys.sleep(.01)
     #set.seed(123)
@@ -475,11 +477,14 @@ if (progress.bar == T) {
       if (is.character(unlist(model.list[i])) == FALSE) {
         character.for.structural.model <- ""
       } else {character.for.structural.model <- "\""}
-      message(paste0("\n",
-                     "Call for ",irt.modelvectorwellnamed[i], "\n",
-                     "mirt::mirt(data = data, ",
-                     "itemtype = \"",irt.modelvector[i],"\", ",
-                     "model = ", character.for.structural.model, unlist(model.list[i]), character.for.structural.model,")"))
+      message(paste0(
+        "\n\u2699\uFE0F Call for ", irt.modelvectorwellnamed[i], ":\n",
+        "mirt::mirt(\n",
+        "  data     = data,\n",
+        "  itemtype = \"", irt.modelvector[i], "\",\n",
+        "  model    = ", character.for.structural.model, unlist(model.list[i]), character.for.structural.model, "\n",
+        ")"
+      ))
     }
 
 
@@ -490,8 +495,10 @@ if (progress.bar == T) {
                       verbose = F,
                       TOL = convergence.threshold,
                       technical = list(NCYCLES = iterations.for.model.comparison,
-                                       warn = F,
+                                       warn = estimation.package.warnings,
                                        message = F))
+    # store the fitted model
+    all_mirt_objects[[irt.modelvectorwellnamed[i]]] <- fit
       modelAIC <- as.numeric(fit@Fit$AIC)
       modelHQ <- as.numeric(fit@Fit$HQ)
       modelBIC <- as.numeric(fit@Fit$BIC)
@@ -538,7 +545,7 @@ if (progress.bar == T) {
 
 if (summary == T) {
   #Message when comparison starts
-  message(paste("\n-== Model Selection (", dim(datainmodelcomparison)[2]," judges) ==-",sep=""))
+  message(paste("\n \U0001F4CC Model Selection (", dim(datainmodelcomparison)[2]," judges) \U0001F4CC ",sep=""))
 }
 
 
@@ -571,10 +578,10 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
 
   if (summary == T) {
   for (i in 1:length(irt.modelvectorwellnamed)) {
-    message(paste(sep=""), shortnameofcomparisonstatistic, " for ",  irt.modelvectorwellnamed[i], ": ",round(comparisonstatistic[i], digits), " | Model weight: ", sprintf("%.3f", round(fit.indices.data.frame$Weights[i], digits)))
+    message(paste(sep=""), "\u25B8 ", shortnameofcomparisonstatistic, " for ",  irt.modelvectorwellnamed[i], ": ",round(comparisonstatistic[i], digits), " | Model weight: ", sprintf("%.3f", round(fit.indices.data.frame$Weights[i], digits)))
   }
 
-  message(paste(" -> The best fitting model is the ",irt.modelvectorwellnamed[positionofbestfittingmodelinlist] ,".\n",sep = ""))
+  message(paste("\U0001F449 The best fitting model is the ",irt.modelvectorwellnamed[positionofbestfittingmodelinlist] ,".",sep = ""))
   }
 
 
@@ -588,7 +595,7 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
 
 
   #Create message to say that we need to use the "sanitized data"
-    messageestimationwithsanitizeddata  <- paste(sep = "", "- Note : The selected model requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed.\n")
+    messageestimationwithsanitizeddata  <- paste(sep = "", "\u2139\uFE0F Note : The selected model requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed.\n")
 
 
 
@@ -608,7 +615,7 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
     structural.model <- 1
     if (numberofjudgestoremove != 0) {
       data <- datasanitized
-      message(paste(sep = "", "\n- Note : The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
+      message(paste(sep = "", "\u26A0\uFE0F The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
       # To return in outputs
       number.of.judges.removed.for.outputs <- numberofjudgestoremove
     }
@@ -623,7 +630,7 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
     if (ratioofjudgestoremove != 0) {
 
       data <- datasanitized
-      message(paste(sep = "", "\n- Note : The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
+      message(paste(sep = "", "\u26A0\uFE0F The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
       # To return in outputs
       number.of.judges.removed.for.outputs <- numberofjudgestoremove
       }
@@ -637,7 +644,7 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
       structural.model <- model.for.constrained.category.structure
       if (ratioofjudgestoremove != 0) {
         data <- datasanitized
-        message(paste(sep = "", "\n- Note : The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
+        message(paste(sep = "", "\u26A0\uFE0F The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
         # To return in outputs
         number.of.judges.removed.for.outputs <- numberofjudgestoremove
       }
@@ -652,7 +659,7 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
     if (ratioofjudgestoremove != 0) {
 
       data <- datasanitized
-      message(paste(sep = "", "\n- Note : The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
+      message(paste(sep = "", "\u26A0\uFE0F The ",irtfullmodelnameforoutputs," requires to use only the judges with all categories observed. ", numberofjudgestoremove, " judge(s) out of ",numberofjudges,  " removed."))
       # To return in outputs
       number.of.judges.removed.for.outputs <- numberofjudgestoremove
     }
@@ -745,7 +752,7 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
 
   # Initial message before estimation
   if (status.verbose == T) {
-    message(paste("Fitting ",
+    message(paste("\u2139\uFE0F Fitting ",
                   irtfullmodelnameforoutputs, " ", authorofmodelforoutputs, "...",
                   sep = "")
     )}
@@ -766,10 +773,14 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
     if (is.numeric(structural.model)==T) {
       character.for.structural.model <- ""
     } else {character.for.structural.model <- "\""}
-    message(paste0("\n",
-                   "Call for selected model:\n","mirt::mirt(data = data, ",
-                   "itemtype = \"",irt.modelnameformirt,"\", ",
-                   "model = ", character.for.structural.model, structural.model, character.for.structural.model,")"))
+    message(paste0(
+      "\n\u2699\uFE0F Call for selected model:\n",
+      "mirt::mirt(\n",
+      "  data     = data,\n",
+      "  itemtype = \"", irt.modelnameformirt, "\",\n",
+      "  model    = ", character.for.structural.model, structural.model, character.for.structural.model, "\n",
+      ")"
+    ))
   }
 
 
@@ -788,6 +799,8 @@ positionofbestfittingmodelinlist <- which.min(comparisonstatistic)
                                        message = estimation.package.warnings)
   )
 
+
+
   #Store info to be displayed
   ## Time elapsed
   timeelapsed <- round(unname(model@time[1]), 2)
@@ -937,12 +950,14 @@ if (sum(missingness.logical.matrix) > 0) {
 
   # Message to signal inputation
   if (missing.data.message == T) {
-    message(paste(sep = "" , "\nThere are ",number.of.incomplete.observations," (", percent.of.incomplete.observations, ") missing observations! Inputing..."))
+    message(paste(sep = "" , "\n\u26A0\uFE0F There are ",number.of.incomplete.observations," (", percent.of.incomplete.observations, ") missing observations! Inputing..."))
   }
 
   # Inpute with mirt
   factorscoresmatrixforinpute <- mirt::fscores(object = model, method = methodfactorscoresformirt)
-  input.missing.data <- mirt::imputeMissing(x = model, Theta = factorscoresmatrixforinpute)
+  input.missing.data <- mirt::imputeMissing(x = model,
+                                            Theta = factorscoresmatrixforinpute,
+                                            warn = estimation.package.warnings)
   imputed <- TRUE
 } else {
   imputed <- FALSE
@@ -979,33 +994,33 @@ if (number.of.judges.removed.for.outputs > 0) {
 } else {additionnal.message.for.judges.removed <- NULL}
 
   if (summary == T) {
-    message(paste(sep="", "\n -== General Summary ==-\n",
-                  "- ", judges.used.in.estimated.model, " ", column.names, "s", additionnal.message.for.judges.removed, "\n",
-                  "- ", sample.size, " Products\n",
-                  "- ", length(response.categories), " response categories (",paste(response.categories, collapse = "-"),")\n"),
-                  "- Mean judgment = ", round(mean(as.numeric(rowMeans(data, na.rm = T))), digits = digits), " | SD = ",round(stats::sd(as.numeric(rowMeans(data, na.rm = T))), digits = digits))
-    message(paste(sep="", "\n-== IRT Summary ==-\n",
-                  "- Model: ", irtfullmodelnameforoutputs," ", authorofmodelforoutputs," | ", doiofirt.model, "\n",
-                  "- Estimation package: ", estimationpackage, " ",apastyleintextcitationofestimationpackage," | ", doiofestimationpackage,"\n",
-                  "- Estimation algorithm: ", estimationalgorithmfullname, " ", authorofestimationalgorithm, " | ", doiofestimationalgorithm, "\n",
+    message(paste(sep="", "\n\U0001F4CC General Summary \U0001F4CC\n",
+                  "\u25B8 ", judges.used.in.estimated.model, " ", column.names, "s", additionnal.message.for.judges.removed, "\n",
+                  "\u25B8 ", sample.size, " Products\n",
+                  "\u25B8 ", length(response.categories), " response categories (",paste(response.categories, collapse = "-"),")\n"),
+                  "\u25B8 Mean judgment = ", round(mean(as.numeric(rowMeans(data, na.rm = T))), digits = digits), " | SD = ",round(stats::sd(as.numeric(rowMeans(data, na.rm = T))), digits = digits))
+    message(paste(sep="", "\n\U0001F4CC IRT Summary \U0001F4CC\n",
+                  "\u25B8 Model: ", irtfullmodelnameforoutputs," ", authorofmodelforoutputs," | ", doiofirt.model, "\n",
+                  "\u25B8 Estimation package: ", estimationpackage, " ",apastyleintextcitationofestimationpackage," | ", doiofestimationpackage,"\n",
+                  "\u25B8 Estimation algorithm: ", estimationalgorithmfullname, " ", authorofestimationalgorithm, " | ", doiofestimationalgorithm, "\n",
 
-                  "- Factor scoring method: ", methodfactorscoresfullname,"\n",
-                  "- AIC = ", round(as.numeric(modelAIC), digits = digits)," |",
+                  "\u25B8 Factor scoring method: ", methodfactorscoresfullname,"\n",
+                  "\u25B8 AIC = ", round(as.numeric(modelAIC), digits = digits)," |",
                   " BIC = ", round(as.numeric(modelBIC), digits = digits)," |",
                   " SABIC = ", round(as.numeric(modelSABIC), digits = digits)," |",
                   " HQ = ", round(as.numeric(modelHQ), digits = digits), "\n",
 
-                  "\n-== Model-based reliability ==-\n",
-                  "- Empirical reliability | Average in the sample: ", numformat(empiricalreliability, digits), "\n",
-                  "- Expected reliability | Assumes a Normal(0,1) prior density: ", numformat(averagedensity, digits), "\n"#,
-               #   "- Normal(-3,1) prior density | Extremely Low abilities : ", numformat(lowlowlowdensity, digits), "\n",
-                #  "- Normal(-2,1) prior density | Very low abilities: ", numformat(lowlowdensity, digits), "\n",
-                #  "- Normal(-1,1) prior density | Low abilities: ", numformat(lowdensity, digits), "\n",
+                  "\n\U0001F4CC Model-based reliability \U0001F4CC\n",
+                  "\u25B8 Empirical reliability | Average in the sample: ", numformat(empiricalreliability, digits), "\n",
+                  "\u25B8 Expected reliability | Assumes a Normal(0,1) prior density: ", numformat(averagedensity, digits), "\n"#,
+               #   "\u25B8 Normal(-3,1) prior density | Extremely Low abilities : ", numformat(lowlowlowdensity, digits), "\n",
+                #  "\u25B8 Normal(-2,1) prior density | Very low abilities: ", numformat(lowlowdensity, digits), "\n",
+                #  "\u25B8 Normal(-1,1) prior density | Low abilities: ", numformat(lowdensity, digits), "\n",
 
-                 # "- Normal(+1,1) prior density | High abilities: ", numformat(highdensity, digits), "\n",
-                #  "- Normal(+2,1) prior density | Very high abilities: ", numformat(highhighdensity, digits), "\n",
-                 # "- Normal(+3,1) prior density | Extremely high abilities: ", numformat(highhighhighdensity, digits)
-#                  "- Pearson correlation between Factor scores and Mean Scores :  ",round(pearson, 3), "\n",
+                 # "\u25B8 Normal(+1,1) prior density | High abilities: ", numformat(highdensity, digits), "\n",
+                #  "\u25B8 Normal(+2,1) prior density | Very high abilities: ", numformat(highhighdensity, digits), "\n",
+                 # "\u25B8 Normal(+3,1) prior density | Extremely high abilities: ", numformat(highhighhighdensity, digits)
+#                  "\u25B8 Pearson correlation between Factor scores and Mean Scores :  ",round(pearson, 3), "\n",
                   ))
  #   if (example.write.up == T) {
       # message(paste(sep="", "\n-== Example write-up ==-\n",
@@ -1014,21 +1029,21 @@ if (number.of.judges.removed.for.outputs > 0) {
 #    }
     if (additional.stats == T) {
       message(paste(sep="",
-                    "-== Other reliability statistics (packages \"irr\" and \"psych\") ==-\n",
-                    "- Cronbach's Alpha: ", numformat(cronbachalpha, digits),"\n",
-                    "- Standardized Cronbach's Alpha : ", numformat(cronbachalphastd, digits), "\n",
-                    "- Guttman's Lambda 4 :", numformat(lambda4maxsplithalf,digits), "\n",
-                    "- Guttman's Lambda 6 :", numformat(lambda6,digits), "\n",
+                    "\U0001F4CC Other reliability statistics (packages \"irr\" and \"psych\") \U0001F4CC\n",
+                    "\u25B8 Cronbach's Alpha: ", numformat(cronbachalpha, digits),"\n",
+                    "\u25B8 Standardized Cronbach's Alpha : ", numformat(cronbachalphastd, digits), "\n",
+                    "\u25B8 Guttman's Lambda 4 :", numformat(lambda4maxsplithalf,digits), "\n",
+                    "\u25B8 Guttman's Lambda 6 :", numformat(lambda6,digits), "\n",
                     #"Average split-half reliability :", numformat(averagesplithalf,digits), "\n",
-                   # "- Omega :", numformat(omegatotal,digits), "\n",
-                  #  "- Omega Hierarchical :", numformat(omegahierarchical,digits), "\n",
-                    "- Fleiss' Kappa : ", numformat(fleisskappa$value, digits),"\n",
-                    "- Fleiss-Conger's Exact Kappa : ", numformat(fleisskappaexactconger$value, digits),"\n",
-                   # "- Ordinal Krippendorf's Alpha : ", numformat(krippendorfordinal$value, digits),"\n",
-                    "- Intraclass Correlation Coefficient (One-Way Consistency model): ", numformat(iccconsistencyoneway$value, digits),"\n",
-                    "- Intraclass Correlation Coefficient (Two-Way Consistency model): ", numformat(iccconsistencytwoway$value, digits),"\n",
-                    "- Intraclass Correlation Coefficient (One-Way Agreement model): ", numformat(iccagreementoneway$value, digits),"\n",
-                    "- Intraclass Correlation Coefficient (Two-Way Agreement model): ", numformat(iccagreementtwoway$value, digits),"\n"))
+                   # "\u25B8 Omega :", numformat(omegatotal,digits), "\n",
+                  #  "\u25B8 Omega Hierarchical :", numformat(omegahierarchical,digits), "\n",
+                    "\u25B8 Fleiss' Kappa : ", numformat(fleisskappa$value, digits),"\n",
+                    "\u25B8 Fleiss-Conger's Exact Kappa : ", numformat(fleisskappaexactconger$value, digits),"\n",
+                   # "\u25B8 Ordinal Krippendorf's Alpha : ", numformat(krippendorfordinal$value, digits),"\n",
+                    "\u25B8 Intraclass Correlation Coefficient (One-Way Consistency model): ", numformat(iccconsistencyoneway$value, digits),"\n",
+                    "\u25B8 Intraclass Correlation Coefficient (Two-Way Consistency model): ", numformat(iccconsistencytwoway$value, digits),"\n",
+                    "\u25B8 Intraclass Correlation Coefficient (One-Way Agreement model): ", numformat(iccagreementoneway$value, digits),"\n",
+                    "\u25B8 Intraclass Correlation Coefficient (Two-Way Agreement model): ", numformat(iccagreementtwoway$value, digits),"\n"))
     }
 
 }
@@ -1100,7 +1115,7 @@ imputed.data <- as.data.frame(imputed.data)
 
   # Warn for non finite values if using ML estimates
   if (methodfactorscoresformirt == "ML") {
-    warning("Maximum Likelihood factor scores are not recommended. Your factor scores may include non finite (-Inf and/or +Inf) estimates with non-computable standard errors. We suggest to use Bayesian estimates instead (EAP, MAP).")
+    warning("Maximum Likelihood factor scores are not recommended. Your factor scores may include non finite (-Inf and/or +Inf) estimates with non-computable standard errors. We suggest to use EAP or MAP estimates.")
   }
 
 
@@ -1110,7 +1125,7 @@ if (sum(missingness.logical.matrix)>0) {
 
   person.fit <- as.data.frame(NULL)
 
-  message("- Note : Person fit statistics based on imputed data! Use with caution!")
+  message("\u26A0\uFE0F Person fit statistics based on imputed data! Use with caution!")
 
   model.complete <- mirt::mirt(data = as.data.frame(input.missing.data),
                       model = 1,
@@ -1155,7 +1170,9 @@ outputobject <- methods::new("jrt",
                     person.fit = person.fit, ### Will have to account there for complete missing
                     local.dependence = local.dependence,
                     column.names = column.names,
-                    mirt.object = model
+                    mirt.object = model,
+                    all.mirt.objects = all_mirt_objects   # <- NEW SLOT HERE
+
                     )
 
 
@@ -1213,7 +1230,8 @@ methods::setClass(Class = "jrt", slots = c(
   sample.size = "numeric",
   number.of.judges.in.model = "numeric",
   column.names = "character",
-  mirt.object = "SingleGroupClass"
+  mirt.object = "SingleGroupClass",
+  all.mirt.objects = "list"
 ))
 
 
@@ -1252,6 +1270,7 @@ methods::setMethod("anova", "jrt", function(object) {mirt::anova(object@mirt.obj
 #'   \item{Judge_3}{Judgments of judge 3}
 #'   \item{Judge_4}{Judgments of judge 4}
 #'   \item{Judge_5}{Judgments of judge 5}
+#'   \item{true_theta}{True value of theta used for simulation.}
 #' }
 "ratings_missing"
 
